#[non_exhaustive]pub enum InternalFSError {
StorageTooSmall,
InvalidBPBSig,
InvalidFSInfoSig,
MismatchingFATTables,
MalformedClusterChain,
MalformedEntryChain,
}Expand description
An error type that denotes that there is something wrong with the filesystem’s structure itself (perhaps the FS itself is malformed/corrupted)
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
StorageTooSmall
The storage medium isn’t large enough to accompany a FAT filesystem
InvalidBPBSig
Invalid boot sector signature. Perhaps this isn’t a FAT filesystem?
InvalidFSInfoSig
Invalid FAT32 FSInfo signature. Perhaps the FSInfo structure or the FAT32 Ebr’s fat_info field is malformed?
MismatchingFATTables
The FAT and it’s copies do not much. This is either the result of some bad FAT library that chose to ignore the FAT copies or perhaps the storage medium has been corrupted (most likely). Either way, we are not handling this FileSystem
MalformedClusterChain
Encountered a malformed cluster chain
MalformedEntryChain
Encountered a malformed directory entry chain